searchNodes=[{"ref":"CLL.html","title":"CLL","type":"module","doc":"This module can be used to represent a data structure with similar behavior as circular Doubly-Linked-List. &quot;But wait, aren&#39;t all Lists in Erlang Linked Lists?&quot; Well yes, but they are immutable, which makes things like removing elements while iterating through the list very slow. Also, getting consistent CLL-like behaviour from normal Lists is not easy when dealing with problems such as polygon math around the beginning and end of the list. Internally, it uses a Zipper data structure (https://en.wikipedia.org/wiki/Zipper_(data_structure)) to keep the items before and after the current item in a way that optimizes for moving forward and backward in the list. Because the next and previous item are always the first items in the surrounding lists, those operations are substantially faster than tracking a cursor in a standar List an fetching its neighbors. A list can be created by passing a List to the init/2 function along with an boolean defining if the resulting Doubly-Linked-List is circular or not. Once created, you can traverse through the list one or more steps at a time. Examples iex&gt; [1, 2, 3, 4, 5] ...&gt; |&gt; CLL.init() ...&gt; |&gt; CLL.value() 1 iex&gt; [1, 2, 3, 4, 5] ...&gt; |&gt; CLL.init() ...&gt; |&gt; CLL.next() ...&gt; |&gt; CLL.value() 2 iex&gt; [1, 2, 3, 4, 5] ...&gt; |&gt; CLL.init() ...&gt; |&gt; CLL.prev() ...&gt; |&gt; CLL.prev(3) ...&gt; |&gt; CLL.next(2) ...&gt; |&gt; CLL.value() 4 You can also modify the list by inserting, replacing, or removing the current element. Finally, if desired, you can convert the CLL back into a List. Examples iex&gt; CLL.init([1, 2, 3, 4, 5]) ...&gt; |&gt; CLL.next(2) ...&gt; |&gt; CLL.remove() ...&gt; |&gt; CLL.to_list() [1, 2, 4, 5] iex&gt; CLL.init([1, 2, 3, 4, 5]) ...&gt; |&gt; CLL.prev(2) ...&gt; |&gt; CLL.replace(:foo) ...&gt; |&gt; CLL.to_list() [1, 2, 3, :foo, 5] iex&gt; CLL.init([1, 2, 3, 4, 5]) ...&gt; |&gt; CLL.next(3) ...&gt; |&gt; CLL.insert(3.5) ...&gt; |&gt; CLL.insert(3.75) ...&gt; |&gt; CLL.to_list() [1, 2, 3, 3.5, 3.75, 4, 5] To help with use cases where iterating through the list once is useful, CLL keeps track of the &quot;start&quot; of the list so that you can determine when a list has been fully traversed. A list can also be reset to the initial start position at any time. Examples iex&gt; CLL.init([1, 2, 3, 4, 5]) ...&gt; |&gt; CLL.next(3) ...&gt; |&gt; CLL.prev(2) ...&gt; |&gt; CLL.next() ...&gt; |&gt; CLL.offset() 2 iex&gt; CLL.init([1, 2, 3, 4, 5]) ...&gt; |&gt; CLL.next(5) ...&gt; |&gt; CLL.done?() true iex&gt; CLL.init([1, 2, 3, 4, 5]) ...&gt; |&gt; CLL.next(4) ...&gt; |&gt; CLL.reset() ...&gt; |&gt; CLL.value() 1"},{"ref":"CLL.html#done?/1","title":"CLL.done?/1","type":"function","doc":""},{"ref":"CLL.html#empty?/1","title":"CLL.empty?/1","type":"function","doc":""},{"ref":"CLL.html#init/1","title":"CLL.init/1","type":"function","doc":""},{"ref":"CLL.html#insert/2","title":"CLL.insert/2","type":"function","doc":""},{"ref":"CLL.html#len/1","title":"CLL.len/1","type":"function","doc":""},{"ref":"CLL.html#next/1","title":"CLL.next/1","type":"function","doc":""},{"ref":"CLL.html#next/2","title":"CLL.next/2","type":"function","doc":""},{"ref":"CLL.html#offset/1","title":"CLL.offset/1","type":"function","doc":""},{"ref":"CLL.html#prev/1","title":"CLL.prev/1","type":"function","doc":""},{"ref":"CLL.html#prev/2","title":"CLL.prev/2","type":"function","doc":""},{"ref":"CLL.html#remove/1","title":"CLL.remove/1","type":"function","doc":""},{"ref":"CLL.html#replace/2","title":"CLL.replace/2","type":"function","doc":""},{"ref":"CLL.html#reset/1","title":"CLL.reset/1","type":"function","doc":""},{"ref":"CLL.html#to_list/1","title":"CLL.to_list/1","type":"function","doc":""},{"ref":"CLL.html#value/2","title":"CLL.value/2","type":"function","doc":""},{"ref":"CLL.html#t:cll/0","title":"CLL.cll/0","type":"type","doc":""},{"ref":"CLL.html#t:value/0","title":"CLL.value/0","type":"type","doc":""}]